package cs636.pizza.presentation;

import org.springframework.boot.SpringApplication;
import org.springframework.boot.WebApplicationType;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.autoconfigure.domain.EntityScan;
import cs636.pizza.config.PizzaSystemConfig;
import org.springframework.boot.Banner;

@SpringBootApplication(scanBasePackages = { "cs636.pizza" })
@EntityScan("cs636.pizza") // apparently only needed when not using embedded tomcat: see SO 28664064
public class ClientApplication {
	public static void main(String[] args) {
		System.out.println("starting ClientApplication...");
		// takes args same as pizza1 SystemTest, after initial arg saying what to run (def. to SystemTest)
		// need to find out jdbc params now, to be able to create emf bean knowing jdbc params
		// see AppConfig.java
		String dbUrl = null;
		String usr = null;
		String pw = null;
		if (args.length <= 1) { // no args: run SystemTest on H2 with test.dat
			// leave dbUrl null, for H2
		} else if (args.length == 4) {
			dbUrl = args[1];
			usr = args[2];
			pw = args[3];
		} else {
			System.out.println("usage:java [<inputFile>] <dbURL> <user> <passwd> ");
			return;
		}
		System.out.println("running ClientApplication with db args: " + dbUrl + " " + usr + " " + pw);

		PizzaSystemConfig.configureJPA(dbUrl, usr, pw); // sets up emf object, for later pickup by Spring bean
		// disabled banner, don't want to see the spring logo
		SpringApplication app = new SpringApplication(ClientApplication.class);
		app.setBannerMode(Banner.Mode.OFF);
		app.setWebApplicationType(WebApplicationType.NONE); // don't start tomcat
		System.out.println("starting ClientRun...");
		app.run(args);
		System.out.println("... ending ClientRun");
	}
}
