package cs636.pizza.dao;

// Example JUnit5 test 
// Important: use this import for Test, not the JUnit4 import for Test
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.extension.ExtendWith;
import org.junit.runner.RunWith;
import org.springframework.test.context.junit.jupiter.SpringExtension;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.domain.EntityScan;
import org.springframework.boot.test.autoconfigure.jdbc.JdbcTest;
import org.springframework.boot.test.autoconfigure.orm.jpa.DataJpaTest;
import org.springframework.boot.test.autoconfigure.orm.jpa.TestEntityManager;
import org.springframework.data.jpa.repository.config.EnableJpaRepositories;
import org.springframework.test.context.ContextConfiguration;
import java.sql.SQLException;

import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import cs636.pizza.config.PizzaSystemConfig;

//@RunWith(SpringRunner.class)
// Junit5--
@ExtendWith(SpringExtension.class)
//Needed to handle DataSource config
//@JdbcTest
@DataJpaTest
//to be minimalistic, configure only the needed beans, avoid using AppConfig
@ContextConfiguration(classes = { DbDAO.class, MenuDAO.class, EntityManager.class })
//use application-test.properties in src/main/resources instead of application.properties

@EnableJpaRepositories(basePackages = {"com.example.*"})
@EntityScan("cs636.pizza")
public class MenuDAOTest {
	@Autowired
	private DbDAO dbDAO;
	@Autowired
	private MenuDAO menuDAO;
	@Autowired
	private EntityManager em;

	@BeforeEach
	public void setup() {
		menuDAO = new MenuDAO(dbDAO);
	}

	@Test
	public void testCreateTopping() throws SQLException {
		menuDAO.createMenuTopping("anchovies");
		int count = menuDAO.findMenuToppings().size();
		Assertions.assertTrue(count == 1, () -> "first topping not created");
	}

	@Test
	// Turn off top-level transaction defaulted tx to allow tx to start in doDupToppings, see failure
	// See https://www.javaer101.com/en/article/81905.html
	@Transactional(propagation = Propagation.NOT_SUPPORTED)
	public void testDuplicateTopping() {
		// With JPA, have various possible Exceptions, so catch them all
		Assertions.assertThrows(Exception.class, () -> {
			doDupToppings();
		});
	}
    @Transactional
	void doDupToppings() {
		System.out.println("in testDup...");
		menuDAO.createMenuTopping("anchovies");
		System.out.println("after first create");
		em.flush();  // suggested online but doesn't help
		menuDAO.createMenuTopping("anchovies");
	}


}
